@@ -1,7 +1,10 @@
 package Astro::Constants;
 # ABSTRACT: this library provides physical constants for use in Astronomy
+$Astro::Constants::VERSION = '0.10.1';
+use strict;
+use warnings;
 
-'They are not constant but are changing still. - Cymbeline, Act II, Scene 5';
+  'They are not constant but are changing still. - Cymbeline, Act II, Scene 5';
 
 __END__
 
@@ -15,15 +18,15 @@ Astro::Constants - this library provides physical constants for use in Astronomy
 
 =head1 VERSION
 
-version 0.09_95
+version 0.10.1
 
 =head1 SYNOPSIS
 
-	use strict;		# important!
+    use strict;		# important!
     use Astro::Constants::MKS qw/:long/;
 
-	# to calculate the gravitational force of the Sun on the Earth in Newtons, use GMm/r^2
-	my $force_sun_earth = GRAVITATIONAL * MASS_SOLAR * MASS_EARTH / ASTRONOMICAL_UNIT**2;
+    # to calculate the gravitational force of the Sun on the Earth in Newtons, use GMm/r^2
+    my $force_sun_earth = GRAVITATIONAL * MASS_SOLAR * MASS_EARTH / ASTRONOMICAL_UNIT**2;
 
 =head1 DESCRIPTION
 
@@ -72,14 +75,15 @@ to check your work?
 
 =head1 METHODS
 
-=head2 LIGHT_SPEED
+=head2 SPEED_LIGHT
 
     2.99792458e8	MKS
     2.99792458e10	CGS
 
 speed of light in a vacuum
 
-This constant can also be accessed through the variable $A_c (which may be deprecated)
+This constant is also available using the short name C<$A_c>
+as well as the alternate name C<LIGHT_SPEED> (imported using the :alternate tag for backwards compatibility)
 
 =head2 BOLTZMANN
 
@@ -88,7 +92,7 @@ This constant can also be accessed through the variable $A_c (which may be depre
 
 Boltzmann's constant
 
-This constant can also be accessed through the variable $A_k (which may be deprecated)
+This constant is also available using the short name C<$A_k>
 
 =head2 GRAVITATIONAL
 
@@ -97,7 +101,7 @@ This constant can also be accessed through the variable $A_k (which may be depre
 
 universal gravitational constant
 
-This constant can also be accessed through the variable $A_G (which may be deprecated)
+This constant is also available using the short name C<$A_G>
 
 =head2 ELECTRON_VOLT
 
@@ -106,7 +110,7 @@ This constant can also be accessed through the variable $A_G (which may be depre
 
 electron volt
 
-This constant can also be accessed through the variable $A_eV (which may be deprecated)
+This constant is also available using the short name C<$A_eV>
 
 =head2 PLANCK
 
@@ -115,16 +119,17 @@ This constant can also be accessed through the variable $A_eV (which may be depr
 
 Planck constant
 
-This constant can also be accessed through the variable $A_h (which may be deprecated)
+This constant is also available using the short name C<$A_h>
 
-=head2 HBAR
+=head2 H_BAR
 
     1.054571800e-34	MKS
     1.054571800e-27	CGS
 
 Planck's constant /2pi
 
-This constant can also be accessed through the variable $A_hbar (which may be deprecated)
+This constant is also available using the short name C<$A_hbar>
+as well as the alternate name C<HBAR> (imported using the :alternate tag for backwards compatibility)
 
 =head2 ELECTRON_CHARGE
 
@@ -133,7 +138,8 @@ This constant can also be accessed through the variable $A_hbar (which may be de
 
 electron charge (defined positive)
 
-This constant can also be accessed through the variable $A_e (which may be deprecated)
+This constant is also available using the short name C<$A_e>
+as well as the alternate name C<CHARGE_ELEMENTARY> (imported using the :alternate tag for backwards compatibility)
 
 =head2 STEFAN_BOLTZMANN
 
@@ -142,16 +148,17 @@ This constant can also be accessed through the variable $A_e (which may be depre
 
 Stefan-Boltzmann constant
 
-This constant can also be accessed through the variable $A_sigma (which may be deprecated)
+This constant is also available using the short name C<$A_sigma>
 
-=head2 A_RAD
+=head2 DENSITY_RADIATION
 
     7.565723e-16	MKS
     7.565723e-15	CGS
 
 radiation density constant, 4 * sigma / c
 
-This constant can also be accessed through the variable $A_arad (which may be deprecated)
+This constant is also available using the short name C<$A_arad>
+as well as the alternate name C<A_RAD> (imported using the :alternate tag for backwards compatibility)
 
 =head2 WIEN
 
@@ -160,7 +167,7 @@ This constant can also be accessed through the variable $A_arad (which may be de
 
 Wien wavelength displacement law constant
 
-This constant can also be accessed through the variable $A_Wien (which may be deprecated)
+This constant is also available using the short name C<$A_Wien>
 
 =head2 ALPHA
 
@@ -169,15 +176,16 @@ This constant can also be accessed through the variable $A_Wien (which may be de
 
 fine structure constant
 
-This constant can also be accessed through the variable $A_alpha (which may be deprecated)
+This constant is also available using the short name C<$A_alpha>
 
-=head2 VACUUM_IMPEDANCE
+=head2 IMPEDANCE_VACUUM
 
     376.730313461
 
 characteristic impedance of vacuum
 
-This constant can also be accessed through the variable $A_Z0 (which may be deprecated)
+This constant is also available using the short name C<$A_Z0>
+as well as the alternate name C<VACUUM_IMPEDANCE> (imported using the :alternate tag for backwards compatibility)
 
 =head2 PERMITIV_FREE_SPACE
 
@@ -186,7 +194,8 @@ This constant can also be accessed through the variable $A_Z0 (which may be depr
 
 permittivity of free space, epsilon_0, the electric constant
 
-This constant can also be accessed through the variable $A_eps0 (which may be deprecated)
+This constant is also available using the short name C<$A_eps0>
+as well as the alternate name C<PERMITIVITY_0> (imported using the :alternate tag for backwards compatibility)
 
 =head2 PERMEABL_FREE_SPACE
 
@@ -195,7 +204,8 @@ This constant can also be accessed through the variable $A_eps0 (which may be de
 
 permeability of free space, mu_0, the magnetic constant
 
-This constant can also be accessed through the variable $A_mu0 (which may be deprecated)
+This constant is also available using the short name C<$A_mu0>
+as well as these alternate names (imported using the :alternate tag): PERMEABILITY_0, CONSTANT_MAGNETIC
 
 =head2 PI
 
@@ -203,7 +213,7 @@ This constant can also be accessed through the variable $A_mu0 (which may be dep
 
 trig constant pi
 
-This constant can also be accessed through the variable $A_pi (which may be deprecated)
+This constant is also available using the short name C<$A_pi>
 
 =head2 EXP
 
@@ -211,7 +221,7 @@ This constant can also be accessed through the variable $A_pi (which may be depr
 
 base of natural logarithm
 
-This constant can also be accessed through the variable $A_exp (which may be deprecated)
+This constant is also available using the short name C<$A_exp>
 
 =head2 ATOMIC_MASS_UNIT
 
@@ -220,7 +230,7 @@ This constant can also be accessed through the variable $A_exp (which may be dep
 
 atomic mass unit, 1 u
 
-This constant can also be accessed through the variable $A_amu (which may be deprecated)
+This constant is also available using the short name C<$A_amu>
 
 =head2 PARSEC
 
@@ -229,7 +239,7 @@ This constant can also be accessed through the variable $A_amu (which may be dep
 
 parsec
 
-This constant can also be accessed through the variable $A_pc (which may be deprecated)
+This constant is also available using the short name C<$A_pc>
 
 =head2 ASTRONOMICAL_UNIT
 
@@ -238,7 +248,7 @@ This constant can also be accessed through the variable $A_pc (which may be depr
 
 astronomical unit
 
-This constant can also be accessed through the variable $A_AU (which may be deprecated)
+This constant is also available using the short name C<$A_AU>
 
 =head2 LIGHT_YEAR
 
@@ -247,7 +257,7 @@ This constant can also be accessed through the variable $A_AU (which may be depr
 
 the distance that light travels in vacuum in one Julian year
 
-This constant can also be accessed through the variable $A_ly (which may be deprecated)
+This constant is also available using the short name C<$A_ly>
 
 =head2 ANGSTROM
 
@@ -256,7 +266,7 @@ This constant can also be accessed through the variable $A_ly (which may be depr
 
 Angstrom
 
-This constant can also be accessed through the variable $A_AA (which may be deprecated)
+This constant is also available using the short name C<$A_AA>
 
 =head2 JANSKY
 
@@ -265,7 +275,7 @@ This constant can also be accessed through the variable $A_AA (which may be depr
 
 Jansky
 
-This constant can also be accessed through the variable $A_Jy (which may be deprecated)
+This constant is also available using the short name C<$A_Jy>
 
 =head2 AVOGADRO
 
@@ -273,7 +283,7 @@ This constant can also be accessed through the variable $A_Jy (which may be depr
 
 Avogadro's number
 
-This constant can also be accessed through the variable $A_NA (which may be deprecated)
+This constant is also available using the short name C<$A_NA>
 
 =head2 YEAR
 
@@ -281,7 +291,8 @@ This constant can also be accessed through the variable $A_NA (which may be depr
 
 defined as exactly 365.25 days of 86400 SI seconds
 
-This constant can also be accessed through the variable $A_yr (which may be deprecated)
+This constant is also available using the short name C<$A_yr>
+as well as the alternate name C<YEAR_JULIAN> (imported using the :alternate tag for backwards compatibility)
 
 =head2 YEAR_TROPICAL
 
@@ -307,32 +318,35 @@ the period between successive passages of the Earth through perihelion
 
 the period between successive passages of the Sun (as seen from the geocenter) through the same lunar node
 
-=head2 SOLAR_MASS
+=head2 MASS_SOLAR
 
     1.9884e30	MKS
     1.9884e33	CGS
 
 solar mass
 
-This constant can also be accessed through the variable $A_msun (which may be deprecated)
+This constant is also available using the short name C<$A_msun>
+as well as the alternate name C<SOLAR_MASS> (imported using the :alternate tag for backwards compatibility)
 
-=head2 SOLAR_LUMINOSITY
+=head2 LUMINOSITY_SOLAR
 
     3.846e26	MKS
     3.846e33	CGS
 
 solar luminosity
 
-This constant can also be accessed through the variable $A_Lsun (which may be deprecated)
+This constant is also available using the short name C<$A_Lsun>
+as well as the alternate name C<SOLAR_LUMINOSITY> (imported using the :alternate tag for backwards compatibility)
 
-=head2 RHO_C
+=head2 DENSITY_CRITICAL_RHOc
 
     1.8791e-26	MKS
     1.8791e-29	CGS
 
 critical density /h^2
 
-This constant can also be accessed through the variable $A_rhoc (which may be deprecated)
+This constant is also available using the short name C<$A_rhoc>
+as well as the alternate name C<RHO_C> (imported using the :alternate tag for backwards compatibility)
 
 =head2 HUBBLE_TIME
 
@@ -340,181 +354,201 @@ This constant can also be accessed through the variable $A_rhoc (which may be de
 
 Hubble time *h, the inverse of Hubble's constant valued at 100 km/s/Mpc (DEPRECATED - see ChangeLog)
 
-This constant can also be accessed through the variable $A_tH (which may be deprecated)
+This constant is also available using the short name C<$A_tH>
 
-=head2 CMB_TEMPERATURE
+=head2 TEMPERATURE_CMB
 
     2.725
 
-cosmic microwave background temperature
+cosmic microwave background temperature in Kelvin
 
-This constant can also be accessed through the variable $A_TCMB (which may be deprecated)
+This constant is also available using the short name C<$A_TCMB>
+as well as the alternate name C<CMB_TEMPERATURE> (imported using the :alternate tag for backwards compatibility)
 
-=head2 SOLAR_V_MAG
+=head2 MAGNITUDE_SOLAR_V
 
     -26.74
 
 solar V magnitude
 
-This constant can also be accessed through the variable $A_Vsun (which may be deprecated)
+This constant is also available using the short name C<$A_Vsun>
+as well as the alternate name C<SOLAR_V_MAG> (imported using the :alternate tag for backwards compatibility)
 
-=head2 SOLAR_V_ABS_MAG
+=head2 MAGNITUDE_SOLAR_V_ABSOLUTE
 
     4.83
 
 solar absolute V magnitude
 
-This constant can also be accessed through the variable $A_MVsun (which may be deprecated)
+This constant is also available using the short name C<$A_MVsun>
+as well as the alternate name C<SOLAR_V_ABS_MAG> (imported using the :alternate tag for backwards compatibility)
 
-=head2 SOLAR_RADIUS
+=head2 RADIUS_SOLAR
 
     6.96e8	MKS
     6.96e10	CGS
 
 solar radius
 
-This constant can also be accessed through the variable $A_rsun (which may be deprecated)
+This constant is also available using the short name C<$A_rsun>
+as well as the alternate name C<SOLAR_RADIUS> (imported using the :alternate tag for backwards compatibility)
 
-=head2 EARTH_MASS
+=head2 MASS_EARTH
 
     5.9722e24	MKS
     5.9722e27	CGS
 
 mass of Earth
 
-This constant can also be accessed through the variable $A_mearth (which may be deprecated)
+This constant is also available using the short name C<$A_mearth>
+as well as the alternate name C<EARTH_MASS> (imported using the :alternate tag for backwards compatibility)
 
-=head2 EARTH_RADIUS
+=head2 RADIUS_EARTH
 
     6.378_136_6e6	MKS
     6.378_136_6e8	CGS
 
 radius of Earth
 
-This constant can also be accessed through the variable $A_rearth (which may be deprecated)
+This constant is also available using the short name C<$A_rearth>
+as well as the alternate name C<EARTH_RADIUS> (imported using the :alternate tag for backwards compatibility)
 
-=head2 SOLAR_TEMPERATURE
+=head2 TEMPERATURE_SOLAR_SURFACE
 
     5778
 
 surface temperature of sun
 
-This constant can also be accessed through the variable $A_Tsun (which may be deprecated)
+This constant is also available using the short name C<$A_Tsun>
+as well as the alternate name C<SOLAR_TEMPERATURE> (imported using the :alternate tag for backwards compatibility)
 
-=head2 SOLAR_DENSITY
+=head2 DENSITY_SOLAR
 
     1408	MKS
     1.408	CGS
 
 mean solar density
 
-This constant can also be accessed through the variable $A_dsun (which may be deprecated)
+This constant is also available using the short name C<$A_dsun>
+as well as the alternate name C<SOLAR_DENSITY> (imported using the :alternate tag for backwards compatibility)
 
-=head2 EARTH_DENSITY
+=head2 DENSITY_EARTH
 
     5514	MKS
     5.514	CGS
 
 mean Earth density
 
-This constant can also be accessed through the variable $A_dearth (which may be deprecated)
+This constant is also available using the short name C<$A_dearth>
+as well as the alternate name C<EARTH_DENSITY> (imported using the :alternate tag for backwards compatibility)
 
-=head2 SOLAR_GRAVITY
+=head2 GRAVITY_SOLAR
 
     274.0	MKS
     27400	CGS
 
 solar surface gravity
 
-This constant can also be accessed through the variable $A_gsun (which may be deprecated)
+This constant is also available using the short name C<$A_gsun>
+as well as the alternate name C<SOLAR_GRAVITY> (imported using the :alternate tag for backwards compatibility)
 
-=head2 EARTH_GRAVITY
+=head2 GRAVITY_EARTH
 
     9.78	MKS
     978	CGS
 
 Earth surface gravity
 
-This constant can also be accessed through the variable $A_gearth (which may be deprecated)
+This constant is also available using the short name C<$A_gearth>
+as well as the alternate name C<EARTH_GRAVITY> (imported using the :alternate tag for backwards compatibility)
 
-=head2 LUNAR_RADIUS
+=head2 RADIUS_LUNAR
 
     1.7381e6	MKS
     1.7381e8	CGS
 
 lunar radius
 
-This constant can also be accessed through the variable $A_rmoon (which may be deprecated)
+This constant is also available using the short name C<$A_rmoon>
+as well as the alternate name C<LUNAR_RADIUS> (imported using the :alternate tag for backwards compatibility)
 
-=head2 LUNAR_MASS
+=head2 MASS_LUNAR
 
     7.342e22	MKS
     7.342e25	CGS
 
 lunar mass
 
-This constant can also be accessed through the variable $A_mmoon (which may be deprecated)
+This constant is also available using the short name C<$A_mmoon>
+as well as the alternate name C<LUNAR_MASS> (imported using the :alternate tag for backwards compatibility)
 
-=head2 LUNAR_SM_AXIS
+=head2 AXIS_SM_LUNAR
 
     3.844e8	MKS
     3.844e10	CGS
 
 lunar orbital semi-major axis
 
-This constant can also be accessed through the variable $A_amoon (which may be deprecated)
+This constant is also available using the short name C<$A_amoon>
+as well as the alternate name C<LUNAR_SM_AXIS> (imported using the :alternate tag for backwards compatibility)
 
-=head2 LUNAR_ECCENTRICITY
+=head2 ECCENTRICITY_LUNAR
 
     0.0549
 
 lunar orbital eccentricity
 
-This constant can also be accessed through the variable $A_emoon (which may be deprecated)
+This constant is also available using the short name C<$A_emoon>
+as well as the alternate name C<LUNAR_ECCENTRICITY> (imported using the :alternate tag for backwards compatibility)
 
-=head2 THOMSON_XSECTION
+=head2 THOMSON_CROSS_SECTION
 
     6.6524587158e-29	MKS
     6.6524587158e-25	CGS
 
 Thomson cross-section
 
-This constant can also be accessed through the variable $A_sigmaT (which may be deprecated)
+This constant is also available using the short name C<$A_sigmaT>
+as well as the alternate name C<THOMSON_XSECTION> (imported using the :alternate tag for backwards compatibility)
 
-=head2 ELECTRON_MASS
+=head2 MASS_ELECTRON
 
     9.10938356e-31	MKS
     9.10938356e-28	CGS
 
 mass of electron
 
-This constant can also be accessed through the variable $A_me (which may be deprecated)
+This constant is also available using the short name C<$A_me>
+as well as the alternate name C<ELECTRON_MASS> (imported using the :alternate tag for backwards compatibility)
 
-=head2 PROTON_MASS
+=head2 MASS_PROTON
 
     1.672621898e-27	MKS
     1.672621898e-24	CGS
 
 mass of proton
 
-This constant can also be accessed through the variable $A_mp (which may be deprecated)
+This constant is also available using the short name C<$A_mp>
+as well as the alternate name C<PROTON_MASS> (imported using the :alternate tag for backwards compatibility)
 
-=head2 NEUTRON_MASS
+=head2 MASS_NEUTRON
 
     1.674927471e-27	MKS
     1.674927471e-24	CGS
 
 neutron mass
 
-This constant can also be accessed through the variable $A_mn (which may be deprecated)
+This constant is also available using the short name C<$A_mn>
+as well as the alternate name C<NEUTRON_MASS> (imported using the :alternate tag for backwards compatibility)
 
-=head2 HYDROGEN_MASS
+=head2 MASS_HYDROGEN
 
     1.67372e-24
 
 mass of Hydrogen atom
 
-This constant can also be accessed through the variable $A_mH (which may be deprecated)
+This constant is also available using the short name C<$A_mH>
+as well as the alternate name C<HYDROGEN_MASS> (imported using the :alternate tag for backwards compatibility)
 
 =head2 MASS_ALPHA
 
@@ -522,25 +556,27 @@ This constant can also be accessed through the variable $A_mH (which may be depr
 
 mass of alpha particle
 
-This constant can also be accessed through the variable $A_ma (which may be deprecated)
+This constant is also available using the short name C<$A_ma>
 
-=head2 ELECTRON_RADIUS
+=head2 RADIUS_ELECTRON
 
     2.8179403227e-15	MKS
     2.8179403227e-13	CGS
 
 classical electron radius
 
-This constant can also be accessed through the variable $A_re (which may be deprecated)
+This constant is also available using the short name C<$A_re>
+as well as the alternate name C<ELECTRON_RADIUS> (imported using the :alternate tag for backwards compatibility)
 
-=head2 BOHR_RADIUS
+=head2 RADIUS_BOHR
 
     5.2917721067e-11	MKS
     5.2917721067e-9	CGS
 
 Bohr radius
 
-This constant can also be accessed through the variable $A_a0 (which may be deprecated)
+This constant is also available using the short name C<$A_a0>
+as well as the alternate name C<BOHR_RADIUS> (imported using the :alternate tag for backwards compatibility)
 
 =head2 pretty
 
@@ -559,39 +595,43 @@ Select from the following tags:
 
 =item *
 
-long		(use this one to get the most constants)
+:long		(use this one to get the most constants)
 
 =item *
 
-short
+:short
 
 =item *
 
-fundamental
+:fundamental
 
 =item *
 
-conversion
+:conversion
 
 =item *
 
-mathematics
+:mathematics
 
 =item *
 
-cosmology
+:cosmology
 
 =item *
 
-planetary
+:planetary
 
 =item *
 
-electromagnetic
+:electromagnetic
 
 =item *
 
-nuclear
+:nuclear
+
+=item *
+
+:alternates
 
 =back
 
@@ -610,19 +650,19 @@ L<Astro::Cosmology>
 
 =item *
 
-L<PDL|Perl Data Language>
+L<Perl Data Language|PDL>
 
 =item *
 
-L<http://physics.nist.gov/|NIST>
+L<NIST|http://physics.nist.gov>
 
 =item *
 
-L<http://asa.usno.navy.mil|Astronomical Almanac>
+L<Astronomical Almanac|http://asa.usno.navy.mil>
 
 =item *
 
-L<http://neilb.org/reviews/constants.html|Neil Bower's review on providing read-only values>
+L<Neil Bower's review on providing read-only values|http://neilb.org/reviews/constants.html>
 
 =item *
 
@@ -635,17 +675,36 @@ L<Test::Deep::NumberTolerant> for testing values within objects
 =back
 
 Reference Documents:
-=for :list
-* L<http://aa.usno.navy.mil/publications/reports/Luzumetal2011.pdf|IAU 2009 system of astronomical constants>
-* L<http://asa.usno.navy.mil/static/files/2016/Astronomical_Constants_2016.pdf|Astronomical Constants 2016.pdf>
-* L<https://www.iau.org/publications/proceedings_rules/units/|IAU recommendations concerning units>
-* L<http://syrte.obspm.fr/IAU_resolutions/Res_IAU2012_B2.pdf|Re-definition of the Astronomical Unit>
+
+=over 4
+
+=item *
+
+L<IAU 2009 system of astronomical constants|http://aa.usno.navy.mil/publications/reports/Luzumetal2011.pdf>
+
+=item *
+
+L<Astronomical Constants 2016.pdf|http://asa.usno.navy.mil/static/files/2016/Astronomical_Constants_2016.pdf>
+
+=item *
+
+L<IAU recommendations concerning units|https://www.iau.org/publications/proceedings_rules/units>
+
+=item *
+
+L<Re-definition of the Astronomical Unit|http://syrte.obspm.fr/IAU_resolutions/Res_IAU2012_B2.pdf>
+
+=back
+
+=head1 REPOSITORY
+
+* L<https://github.com/duffee/Astro-Constants>
 
 =head1 ISSUES
 
-File issues/suggestions at the Github repository L<https://github.com/duffee/Astro-Constants/>.
-The venerable L<https://rt.cpan.org/Dist/Display.html?Status=Active&Queue=Astro-Constants|RT>
-is the canonical bug tracker that is clocked by L<https://metacpan.org/pod/Astro::Constants|meta::cpan>.
+File issues/suggestions at the Github repository L<https://github.com/duffee/Astro-Constants>.
+The venerable L<RT|https://rt.cpan.org/Dist/Display.html?Status=Active&Queue=Astro-Constants>
+is the canonical bug tracker that is clocked by L<meta::cpan|https://metacpan.org/pod/Astro::Constants>.
 
 Using C<strict> is a must with this code.  Any constants you forgot to import will
 evaluate to 0 and silently introduce errors in your code.  Caveat Programmer.
@@ -656,7 +715,7 @@ disposal, including
 What new features would you like to see?
 If you've had an experience with using the module, let other people know what you
 think, good or bad, by rating it at
-L<http://cpanratings.perl.org/rate/?distribution=Astro-Constants|cpanratings>.
+L<cpanratings|http://cpanratings.perl.org/rate/?distribution=Astro-Constants>.
 
 =head2 Extending the data set
 
@@ -680,7 +739,7 @@ important information coming at the beginning of the name.
 =head1 ASTROCONST  X<ASTROCONST>
 
 (Gleaned from the Astroconst home page -
-L<http://web.astroconst.org|http://web.astroconst.org> )
+L<astroconst.org|http://web.astroconst.org> )
 
 Astroconst is a set of header files in various languages (currently C,
 Fortran, Perl, Java, IDL and Gnuplot) that provide a variety of useful
@@ -723,11 +782,11 @@ documentation.
 
 =head1 AUTHOR
 
-Boyd Duffee <duffee at cpan.org>
+Boyd Duffee <duffee@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Boyd Duffee.
+This software is copyright (c) 2016 by Boyd Duffee.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
